pub struct OITResolvePipeline {
pipeline: RenderPipeline,
}Fields
pipeline: RenderPipelineImplementations
Sourceimpl OITResolvePipeline
impl OITResolvePipeline
pub fn depth_bind_group_layout(ctx: &WgpuContext) -> BindGroupLayout
Methods from Deref<Target = RenderPipeline>
pub fn get_bind_group_layout(&self, index: u32) -> BindGroupLayout
pub fn get_bind_group_layout(&self, index: u32) -> BindGroupLayout
Get an object representing the bind group layout at a given index.
If this pipeline was created with a [default layout][RenderPipelineDescriptor::layout], then
bind groups created with the returned BindGroupLayout can only be used with this pipeline.
This method will raise a validation error if there is no bind group layout at index.